@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2001, 2005, 2007, 2009-2012, 2014-2017 Free
-   Software Foundation, Inc.
+   Copyright (C) 1999-2024 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -20,6 +19,7 @@
 #define _MAILUTILS_AUTH_H
 
 #include <mailutils/types.h>
+#include <mailutils/locus.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -74,10 +74,13 @@ void *mu_wicket_get_data (mu_wicket_t wicket);
 int mu_wicket_set_get_ticket (mu_wicket_t wicket,
 			      int (*_get_ticket) (mu_wicket_t, void *,
 						 const char *, mu_ticket_t *));
+
+int mu_noauth_ticket_create (mu_ticket_t *pticket);
+int mu_noauth_wicket_create (mu_wicket_t *pwicket);
 int mu_file_wicket_create (mu_wicket_t *pwicket, const char *filename);
 
 struct mu_debug_locus;  
-int mu_wicket_stream_match_url (mu_stream_t stream, struct mu_locus *loc,
+int mu_wicket_stream_match_url (mu_stream_t stream, struct mu_locus_point *loc,
 				mu_url_t url, int parse_flags,
 				mu_url_t *pticket_url);
 int mu_wicket_file_match_url (const char *name, mu_url_t url,
