@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2020 Free Software Foundation, Inc.
+   Copyright (C) 1999-2024 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -19,6 +19,7 @@
 # define _MAILUTILS_SYS_LIST_H
 
 # include <sys/types.h>
+# include <string.h>
 
 # include <mailutils/list.h>
 # include <mailutils/monitor.h>
@@ -45,6 +46,19 @@ struct _mu_list
   struct _mu_iterator *itr;
 };
 
+static inline struct list_data *
+_mu_list_null (struct _mu_list *lst)
+{
+  return &lst->head;
+}
+  
+static inline void
+_mu_list_init (struct _mu_list *lst)
+{
+  memset (lst, 0, sizeof *lst);
+  lst->head.prev = lst->head.next = &lst->head;
+}
+
 #define DESTROY_ITEM(list, elt)			\
   do						\
     {						\
